==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescriptionMetadata } from "./WebFilteringOperationDescriptionMetadata";
import { WebFilteringOperandDescription } from "./WebFilteringOperandDescription";
/**
 * @hidden
 */
export let WebFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringOperandDescriptionMetadata.a == null) {
                WebFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringOperandDescriptionMetadata.c(WebFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFilteringOperandDescriptionMetadata.a);
            WebFilteringOperationDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("Operations", "Array:WebFilteringOperationDescription:FilteringOperation");
        }
        static d(a) {
            WebFilteringOperandDescriptionMetadata.b(a);
            a.ad("WebFilteringOperand", () => new WebFilteringOperandDescription());
            a.ac("WebFilteringOperand", WebFilteringOperandDescriptionMetadata.a);
        }
    }
    WebFilteringOperandDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringOperandDescriptionMetadata, 'WebFilteringOperandDescriptionMetadata');
    WebFilteringOperandDescriptionMetadata.a = null;
    return WebFilteringOperandDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescriptionMetadata } from "./WebFilteringOperationDescriptionMetadata";
import { WebFilteringOperandDescription } from "./WebFilteringOperandDescription";
/**
 * @hidden
 */
export let WebFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringOperandDescriptionMetadata.a == null) {
                WebFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringOperandDescriptionMetadata.c(WebFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFilteringOperandDescriptionMetadata.a);
            WebFilteringOperationDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("Operations", "Array:WebFilteringOperationDescription:FilteringOperation");
        }
        static d(a) {
            WebFilteringOperandDescriptionMetadata.b(a);
            a.ae("WebFilteringOperand", () => new WebFilteringOperandDescription());
            a.ad("WebFilteringOperand", WebFilteringOperandDescriptionMetadata.a);
        }
    }
    WebFilteringOperandDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringOperandDescriptionMetadata, 'WebFilteringOperandDescriptionMetadata');
    WebFilteringOperandDescriptionMetadata.a = null;
    return WebFilteringOperandDescriptionMetadata;
})();
